---
height: 4
---

# Migration Progress

> If widgets show `Unable to render visualization.` verify if
> the [UCX catalog exists](https://github.com/databrickslabs/ucx?tab=readme-ov-file#create-ucx-catalog-command).

This dashboard displays the migration progress, with data visualized from the `migration-progress-experimental`
workflow. This workflow is designed to run regularly — either daily or weekly — to provide an up-to-date overview of the
migration progress.

In addition to offering real-time insights into migration progress, the dashboard also facilitates planning and task
division. For instance, you can choose to migrate one workspace or schema at a time. By assigning a migration owner to
each workspace and/or schema, the dashboard shows how the resources allocated to that owner are progressing.
